Documentation
¶
Index ¶
- Variables
- func AuthenticateVault(v *api.VaultInfo, attempt int, lastErr error) ([]byte, error)
- func GetNewPassword(label string) (string, error)
- func GetOnePassword(ref string) ([]byte, error)
- func GetPassword(long, short string, rd io.Reader, wr io.Writer, mask bool) (string, error)
- func ResolveOnePassword(itemName, fieldLabel string) (string, error)
- func ValidateDependencies()
- type OnePasswordField
Constants ¶
This section is empty.
Variables ¶
var PinEntryMode string
Functions ¶
func AuthenticateVault ¶
func GetNewPassword ¶
func GetOnePassword ¶
func GetPassword ¶
func ResolveOnePassword ¶
func ValidateDependencies ¶ added in v0.7.0
func ValidateDependencies()
ValidateDependencies checks that security-critical dependencies (namely, go-pinentry) are audited when they are updated.
The pinentry library is used to read secret data. Therefore it must be audited. If the pinentry library is updated without updating this function, the program will print a warning. This makes it harder to accidentally update the library without auditing it.
I wanted to make this exit the program, but I couldn't figure out how to reliably detect if the program was running in a test environment.
Types ¶
Click to show internal directories.
Click to hide internal directories.